@@ -9,6 +9,7 @@ use serde::Deserialize;
 use crate::broker_statement::open::common::deserialize_date;
 use crate::broker_statement::partial::PartialBrokerStatement;
 use crate::core::GenericResult;
+use crate::exchanges::Exchange;
 use crate::time::{Date, Period};
 
 use cash_assets::CashAssets;
@@ -34,7 +35,7 @@ pub struct BrokerReport {
 
 impl BrokerReport {
     pub fn parse(&self) -> GenericResult<PartialBrokerStatement> {
-        let mut statement = PartialBrokerStatement::new(true);
+        let mut statement = PartialBrokerStatement::new(&[Exchange::Spb], true);
         statement.period.replace(Period::new(self.date_from, self.date_to)?);
 
         let mut has_starting_assets = self.cash_assets.parse(&mut statement)?;
